Mac

Struct Mac 

pub struct Mac(/* private fields */);
A media access control (MAC) address.

MAC addresses are used to identify devices in the Ethernet protocol.

MAC addresses can be derived from multicast IP addresses; see the From implementation for more details.

Layout

Mac has the same layout as [u8; 6], which is the layout that most protocols use to represent a MAC address in their packet formats. This can be useful when parsing a MAC address from a packet. For example:

/// The header of an Ethernet frame.
///
/// `EthernetHeader` has the same layout as the header of an Ethernet frame.
#[repr(C)]
struct EthernetHeader {
    dst: Mac,
    src: Mac,
    ethertype: [u8; 2],
}

Implementations

Source

impl Mac

pub const BYTES: usize = 6

The number of bytes in a Mac address.

pub const BROADCAST: Mac

The broadcast MAC address.

The broadcast MAC address, FF:FF:FF:FF:FF:FF, indicates that a frame should be received by all receivers regardless of their local MAC address.

pub const DEFAULT_EUI_MAGIC: [u8; 2]

The default RFC 4291 EUI-64 magic value used by the to_eui64 method.

pub const UNSPECIFIED: Mac

The all-zeroes MAC address.

pub const fn new(bytes: [u8; 6]) -> Mac

Constructs a new MAC address.

pub const fn bytes(self) -> [u8; 6]

Gets the bytes of the MAC address.

pub fn to_eui64(self) -> [u8; 8]

Returns the RFC 4291 EUI-64 interface identifier for this MAC address with the default EUI magic value.

mac.to_eui64() is equivalent to mac.to_eui64_with_magic(Mac::DEFAULT_EUI_MAGIC).

pub fn to_eui64_with_magic(self, eui_magic: [u8; 2]) -> [u8; 8]

Returns the RFC 4291 EUI-64 interface identifier for this MAC address with a custom EUI magic value.

eui_magic is the two bytes that are inserted between the bytes of the MAC address to form the identifier. Also see the to_eui64 method, which uses the default magic value of 0xFFFE.

Returns the link-local unicast IPv6 address and subnet for this MAC address, as per [RFC 4862], with the default EUI magic value.

mac.to_ipv6_link_local() is equivalent to mac.to_ipv6_link_local_with_magic(Mac::DEFAULT_EUI_MAGIC).

Returns the link-local unicast IPv6 address and subnet for this MAC address, as per RFC 4862.

eui_magic is the two bytes that are inserted between the bytes of the MAC address to form the identifier. Also see the to_ipv6_link_local method, which uses the default magic value of 0xFFFE.

The subnet prefix length is 128 - Ipv6::UNICAST_INTERFACE_IDENTIFIER_BITS.